==> Tagz-1.0.0.zip: Tagz/lang/pl.php <==
<?php
$LANG = array(
 'P_MENU'=>'0',
 'L_MENU_TAGS'=>'Słowa kluczowe',
 'L_TITLE'=>'Edytuj słowa kluczowe witryny',
 'L_DESCRIPTION'=>'Zarządzaj tagami witryny. Usuń lub zmień nazwę zestawu słów kluczowych.',
#admin
 'L_CANCEL'=>'Anuluj wszystko',
 'L_DEVIENT'=>'staje',
 'L_POUR'=>'dla',
 'L_SEARCH'=>'Szukaj w artykułach z tym słowem kluczowym',
 'L_RESTORE'=>'przywracać',
 'L_DEL'=>'wymazać',
 'L_RESTORE_ALL'=>'Przywróć wszystkie puste pola',
 'L_DEL_ALL'=>'Wyczyść wszystkie pola',
 'L_ART_NUM'=>'Dla przedmiotu (-ów) o numerach (-ach)',
 'L_HELP_TAG_FIELD'=>'Jeśli pole jest puste, usuwa słowo kluczowe po zapisaniu.'.PHP_EOL.'La combinaison de touche Ctrl + z permet d’annuler',
 'L_TAGS_REFRESH'=>'Odśwież',
 'L_TAGS_REFRESHED_BY_ARTICLES'=>'Plik Tags.xml odświeżony o słowa kluczowe artykułów',
 'L_TAG_PLACEHOLDER'=>'Usunięte, jeśli pozostawione puste',
 'L_DEDUPLICATED'=>'deduplikowane',
 'L_IN_REALITY'=>'W rzeczywistości',
 'L_IS_UNIK'=>'Unikalny (jest solo)',
 'L_DOUBLES'=>'podwójny',
 'L_TRIPLES'=>'trójki',
 'L_QUADRUPLES'=>'poczwórny',
 'L_QUINTUPLES'=>'pięciokrotny',
 'L_SEXTUPLES'=>'Sześcioosobowy',
 'L_SEPTUPLES'=>'siedmiokrotnie',
#config
 'L_ACCES'=>'Typ (y) kont (e) * uprawniony do dostępu do wtyczki',
 'L_HELP_ACCES'=>'Które profile * mogą korzystać z wtyczki. Lista oddzielona przecinkami (domyślnie PROFIL_ADMIN, PROFIL_MANAGER).',
 'L_DENY'=>'Użytkownik (użytkownicy) nie ma dostępu do wtyczki (ukryte menu)',
 'L_HELP_DENY'=>'Jakie są identyfikatory użytkowników, którym zabroniono korzystać z wtyczki. Lista rozdzielana przecinkami (na przykład 001,002,007).'
);
?>

==> Tagz-1.0.4.zip: Tagz/lang/pl.php <==
<?php
$LANG = array(
 'P_MENU'=>'0',
 'L_MENU_TAGS'=>'Słowa kluczowe',
 'L_TITLE'=>'Edytuj słowa kluczowe witryny',
 'L_DESCRIPTION'=>'Zarządzaj tagami witryny. Usuń lub zmień nazwę zestawu słów kluczowych.',
 'L_FILTER_TAGS'=>'Filtruj słowa kluczowe',
 'L_FILTER_TAGS_PH'=>'Filtr programu Word',
 'L_CANCEL'=>'Anuluj wszystko',
 'L_DEVIENT'=>'staje',
 'L_POUR'=>'dla',
 'L_SEARCH'=>'Szukaj w artykułach z tym słowem kluczowym',
 'L_RESTORE'=>'przywracać',
 'L_DEL'=>'wymazać',
 'L_RESTORE_ALL'=>'Przywróć wszystkie puste pola',
 'L_DEL_ALL'=>'Wyczyść wszystkie pola',
 'L_ART_NUM'=>'Dla przedmiotu (-ów) o numerach (-ach)',
 'L_HELP_TAG_FIELD'=>'Jeśli pole jest puste, usuwa słowo kluczowe po zapisaniu.',
 'L_HELP_TAG_CTRLZ'=>'Połączenie klawiszy Ctrl-z umożliwia anulowanie',
 'L_TAGS_REFRESH'=>'Odśwież',
 'L_TAGS_REFRESHED_BY_ARTICLES'=>'Plik Tags.xml odświeżony o słowa kluczowe artykułów',
 'L_TAG_PLACEHOLDER'=>'Usunięte, jeśli pozostawione puste',
 'L_DEDUPLICATED'=>'deduplikowane',
 'L_IN_REALITY'=>'W rzeczywistości',
 'L_IS_UNIK'=>'Unikalny (jest solo)',
 'L_DOUBLES'=>'podwójny',
 'L_TRIPLES'=>'trójki',
 'L_QUADRUPLES'=>'poczwórny',
 'L_QUINTUPLES'=>'pięciokrotny',
 'L_SEXTUPLES'=>'Sześcioosobowy',
 'L_SEPTUPLES'=>'siedmiokrotnie',
 'L_OCTUPLES'=>'Octuples (wa.',
 'L_NONUPLES'=>'Nonuples (Nieuples)',
 'L_DECUPLES'=>'Dziesięciokrotnie',
#config
 'L_ACCES'=>'Typ (y) kont (e) * uprawniony do dostępu do wtyczki',
 'L_HELP_ACCES'=>'Które profile * mogą korzystać z wtyczki. Lista oddzielona przecinkami (domyślnie PROFIL_ADMIN, PROFIL_MANAGER).',
 'L_DENY'=>'Użytkownik (użytkownicy) nie ma dostępu do wtyczki (ukryte menu)',
 'L_HELP_DENY'=>'Jakie są identyfikatory użytkowników, którym zabroniono korzystać z wtyczki. Lista rozdzielana przecinkami (na przykład 001,002,007).',
);
?>
